@@ -3,16 +3,10 @@
 
 #undef NDEBUG
 
-#include "../src/filesystem.h"
-
 #include "lilv/lilv.h"
-#include "serd/serd.h"
 
 #include <assert.h>
-#include <stdbool.h>
-#include <stdint.h>
 #include <stdio.h>
-#include <stdlib.h>
 
 #define PLUGIN_URI "http://example.org/missing-name"
 
@@ -28,12 +22,8 @@ main(int argc, char** argv)
   LilvWorld*  world       = lilv_world_new();
 
   // Load test plugin bundle
-  uint8_t*  abs_bundle = (uint8_t*)lilv_path_absolute(bundle_path);
-  SerdNode  bundle     = serd_node_new_file_uri(abs_bundle, 0, 0, true);
-  LilvNode* bundle_uri = lilv_new_uri(world, (const char*)bundle.buf);
+  LilvNode* bundle_uri = lilv_new_file_uri(world, NULL, bundle_path);
   lilv_world_load_bundle(world, bundle_uri);
-  free(abs_bundle);
-  serd_node_free(&bundle);
   lilv_node_free(bundle_uri);
 
   LilvNode*          plugin_uri = lilv_new_uri(world, PLUGIN_URI);
