@@ -122,6 +122,12 @@ create_test_directories(void)
   dirs.copy    = zix_path_join(NULL, dirs.shared, "copy");
   dirs.link    = zix_path_join(NULL, dirs.shared, "link");
 
+  assert(dirs.top);
+  assert(dirs.shared);
+  assert(dirs.scratch);
+  assert(dirs.copy);
+  assert(dirs.link);
+
   assert(!mkdir(dirs.shared, 0700));
   assert(!mkdir(dirs.scratch, 0700));
   assert(!mkdir(dirs.copy, 0700));
@@ -553,7 +559,8 @@ count_statements(const char* path)
 
   SerdNode uri = serd_node_new_file_uri((const uint8_t*)path, NULL, NULL, true);
 
-  assert(!serd_reader_read_file(reader, uri.buf));
+  assert(uri.buf);
+  assert(!serd_reader_read_file(reader, (const uint8_t*)uri.buf));
 
   serd_node_free(&uri);
   serd_reader_free(reader);
@@ -1017,6 +1024,18 @@ test_bad_subject(void)
   test_context_free(ctx);
 }
 
+static void
+test_missing_path(void)
+{
+  TestContext* const ctx   = test_context_new();
+  LilvState* const   state = lilv_state_new_from_file(
+    ctx->env->world, &ctx->map, NULL, "/does/not/exist");
+
+  assert(!state);
+
+  test_context_free(ctx);
+}
+
 static void
 count_file(const char* path, const char* name, void* data)
 {
@@ -1105,6 +1124,7 @@ main(void)
   test_world_round_trip();
   test_label_round_trip();
   test_bad_subject();
+  test_missing_path();
   test_delete();
 
   return 0;
